Hoo man has uploaded a new change for review.

  https://gerrit.wikimedia.org/r/295554

Change subject: Log PHP/HHVM errors in CLI mode to stderr, not stdout
......................................................................

Log PHP/HHVM errors in CLI mode to stderr, not stdout

Per the PHP documentation: 
https://secure.php.net/manual/en/errorfunc.configuration.php#ini.display-errors
Checked to be also implemented in HHVM (at least in recent
versions).

Bug: T138291
Change-Id: Iff9fe91fd0969444a7f280726b1757082bca5428
---
M wmf-config/CommonSettings.php
1 file changed, 3 insertions(+), 3 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/operations/mediawiki-config 
refs/changes/54/295554/1

diff --git a/wmf-config/CommonSettings.php b/wmf-config/CommonSettings.php
index b90d0fd..4d46995 100644
--- a/wmf-config/CommonSettings.php
+++ b/wmf-config/CommonSettings.php
@@ -31,9 +31,9 @@
        $_SERVER['SERVER_SOFTWARE'] = 'Apache';
 }
 
-if ( PHP_SAPI == 'cli' ) {
-       # Override for sanity's sake.
-       ini_set( 'display_errors', 1 );
+if ( PHP_SAPI === 'cli' ) {
+       # Override for sanity's sake. Log errors to stderr.
+       ini_set( 'display_errors', 'stderr' );
 }
 if ( isset( $_SERVER['SERVER_ADDR'] ) ) {
        ini_set( 'error_append_string', ' (' . $_SERVER['SERVER_ADDR'] . ')' );

-- 
To view, visit https://gerrit.wikimedia.org/r/295554
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: Iff9fe91fd0969444a7f280726b1757082bca5428
Gerrit-PatchSet: 1
Gerrit-Project: operations/mediawiki-config
Gerrit-Branch: master
Gerrit-Owner: Hoo man <h...@online.de>

_______________________________________________
MediaWiki-commits mailing list
MediaWiki-commits@lists.wikimedia.org
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to